summaryrefslogtreecommitdiffstats
path: root/Process.h
diff options
context:
space:
mode:
Diffstat (limited to 'Process.h')
-rw-r--r--Process.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/Process.h b/Process.h
index 96b90bce..2350775f 100644
--- a/Process.h
+++ b/Process.h
@@ -102,8 +102,8 @@ typedef struct Process_ {
*/
char* cmdline;
- /* Offset in cmdline of the process basename */
- int cmdlineBasenameOffset;
+ /* End Offset in cmdline of the process basename */
+ int cmdlineBasenameEnd;
/* Start Offset in cmdline of the process basename */
int cmdlineBasenameStart;